summaryrefslogtreecommitdiffstats
path: root/misc/scripts/install_d3d12_sdk_windows.py
diff options
context:
space:
mode:
authorRandolph W. Aarseth II <bioblazepayne@gmail.com>2024-10-04 01:37:26 -0700
committerSpartan322 <Megacake1234@gmail.com>2024-10-11 02:25:54 -0400
commitd5fc3d1e8c1f8f904e1fbe8bd1c402d560bfb596 (patch)
treee3d74332dbb7b5fe280d370b94e0fde913d78be8 /misc/scripts/install_d3d12_sdk_windows.py
parentb52811b83478bd06c5bcf39a93bbf53dd03cc9bf (diff)
downloadredot-engine-d5fc3d1e8c1f8f904e1fbe8bd1c402d560bfb596.tar.gz
Rebrand Godot to Redot
Add Linux Editor tests workflow matrix Add Windows Editor w/ Mono workflow matrix Add Generate Glue Code job to Windows workflow Add Build GodotSharp job to Windows workflow Add godot compatibility version references Add Godot author info Add Godot version compatibility info Add Godot donor info Add Godot authors and donors to editor_about.cpp Credits: Co-authored-by: Skogi <skogi.b@gmail.com> Co-authored-by: Spartan322 <Megacake1234@gmail.com> Co-authored-by: swashberry <swashdev@pm.me> Co-authored-by: Christoffer Sundbom <christoffer_karlsson@live.se> Co-authored-by: Dubhghlas McLaughlin <103212704+mcdubhghlas@users.noreply.github.com> Co-authored-by: McDubh <103212704+mcdubhghlas@users.noreply.github.com> Co-authored-by: Dubhghlas McLaughlin <103212704+mcdubhghlas@users.noreply.github.com> Co-authored-by: radenthefolf <radenthefolf@gmail.com> Co-authored-by: John Knight <80524176+Tekisasu-JohnK@users.noreply.github.com> Co-authored-by: Adam Vondersaar <adam.vondersaar@uphold.com> Co-authored-by: decryptedchaos <nixgod@gmail.com> Co-authored-by: zaftnotameni <122100803+zaftnotameni@users.noreply.github.com> Co-authored-by: Aaron Benjamin <lifeartstudios@gmail.com> Co-authored-by: wesam <108880473+wesamdev@users.noreply.github.com> Co-authored-by: Mister Puma <MisterPuma80@gmail.com> Co-authored-by: Aaron Benjamin <lifeartstudios@gmail.com> Co-authored-by: SingleError <isaaconeoneone@gmail.com> Co-authored-by: Bioblaze Payne <BioblazePayne@gmail.com>
Diffstat (limited to 'misc/scripts/install_d3d12_sdk_windows.py')
-rwxr-xr-xmisc/scripts/install_d3d12_sdk_windows.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/misc/scripts/install_d3d12_sdk_windows.py b/misc/scripts/install_d3d12_sdk_windows.py
index 2e5e4fce18..a52376672b 100755
--- a/misc/scripts/install_d3d12_sdk_windows.py
+++ b/misc/scripts/install_d3d12_sdk_windows.py
@@ -17,7 +17,7 @@ if sys.platform == "win32":
mode = c_int(mode.value | 4)
windll.kernel32.SetConsoleMode(c_int(stdout_handle), mode)
# Base Godot dependencies path
# If cross-compiling (no LOCALAPPDATA), we install in `bin`
deps_folder = os.getenv("LOCALAPPDATA")
if deps_folder:
@@ -124,4 +124,4 @@ print(f"DirectX 12 Agility SDK {agility_sdk_version} installed successfully.\n")
# Complete message
print(f'\x1b[92mAll Direct3D 12 SDK components were installed to "{deps_folder}" successfully!\x1b[0m')
-print('\x1b[92mYou can now build Godot with Direct3D 12 support enabled by running "scons d3d12=yes".\x1b[0m')
+print('\x1b[92mYou can now build Redot with Direct3D 12 support enabled by running "scons d3d12=yes".\x1b[0m')
@@ -17,7 +17,7 @@ if sys.platform == "win32":
mode = c_int(mode.value | 4)
windll.kernel32.SetConsoleMode(c_int(stdout_handle), mode)
-# Base Godot dependencies path
+# Base Redot dependencies path
# If cross-compiling (no LOCALAPPDATA), we install in `bin`
deps_folder = os.getenv("LOCALAPPDATA")